#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml
version: 1.3.14
id: xml-1.3.14-6291d85df68e094bfca87f33fea8b24c
key: xml_AyrkYt7P0aQDgNiMBs2bvw
license: BSD3
copyright: (c) 2007-2008 Galois Inc.
maintainer: diatchki@galois.com
homepage: http://code.galois.com
synopsis: A simple XML library.
description:
    A simple XML library.
category: Text, XML
author: Galois Inc.
exposed: True
exposed-modules:
    Text.XML.Light Text.XML.Light.Types Text.XML.Light.Output
    Text.XML.Light.Input Text.XML.Light.Lexer Text.XML.Light.Proc
    Text.XML.Light.Cursor
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/xml-1.3.14
library-dirs: /usr/lib/ghc-7.10.3/site-local/xml-1.3.14
data-dir: /usr/share/arm-linux-ghc-7.10.3/xml-1.3.14
hs-libraries: HSxml-1.3.14-AyrkYt7P0aQDgNiMBs2bvw
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
haddock-interfaces: /usr/share/doc/haskell-xml/html/xml.haddock
haddock-html: /usr/share/doc/haskell-xml/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
